@@ -17,7 +17,7 @@ def parse_raw_df(df_hour_raw, time_zone):
         charging_names = ['Percentage', 'isCharging', 'isUSBCharging', 'isACCharging', 'isWirelessCharging']
         df_temp.columns = charging_names
         df_hour_raw = df_hour_raw.drop(dropped_columns, axis=1)
-        df_hour_raw.columns = ['Local_Time']
+        df_hour_raw.columns = ['LOG_TIME']
 
         for col_name in charging_names:
             df_hour_raw[col_name] = df_temp[col_name]
