@@ -11,8 +11,8 @@ def parse_raw_df(df_hour_raw, time_zone):
     if df_hour_raw.shape[0] > 0:
         df_hour_raw = df_hour_raw.drop(dropped_columns, axis=1)
         df_hour_raw = df_hour_raw.dropna(how='any', axis=0)
-        df_hour_raw['HEADER_TIME_STAMP'] = [x + " " + time_zone for x in df_hour_raw['HEADER_TIME_STAMP']]
-        df_hour_raw['START_TIME'] = [x + " " + time_zone for x in df_hour_raw['START_TIME']]
+        df_hour_raw['LOG_TIME'] = [x + " " + time_zone for x in df_hour_raw['HEADER_TIME_STAMP']]
+        df_hour_raw['EVENT_TIME'] = [x + " " + time_zone for x in df_hour_raw['START_TIME']]
     return df_hour_raw
 
 
