@@ -4,8 +4,8 @@ from os import path, sep, getcwd
 import importlib
 import time
 import shutil
-import preprocess_scripts
-# import preprocessing_all_uema
+import time_study_preprocessing_main.preprocess_scripts
+import time_study_preprocessing_main.preprocessing_all_uema
 from time_study_preprocessing_main.preprocessing_all_uema import run_uema_main
 
 
@@ -17,6 +17,7 @@ def preprocessing_start(microT_root_path, intermediate_file_save_path, decrypt_p
     information_list = ["app_usage", "app_use_duration", "battery", "daily_notes", "detected_activity", "GPS",
                         "notif_logs", "phone_broadcasts", "prompt_response", "step_count", "wifi_state",
                         "apps_installed", "daily_report", "ringer_mode", "location_cluster_json"]
+    # information_list = []
     # parse information and participants text file
     # information_list = preprocess_scripts.utils.parse_information.parse_information(information_text_file_path)
     p_id_list = []
@@ -85,7 +86,7 @@ def run_ema_main(microT_root_path, intermediate_file_save_path, decrypt_password
 
     # output summary report
     # if date_start == date_end:
-    preprocess_scripts.utils.output_summary_report.generate_output_report(microT_root_path, intermediate_file_save_path,
+    time_study_preprocessing_main.preprocess_scripts.utils.output_summary_report.generate_output_report(microT_root_path, intermediate_file_save_path,
                                                                           date)
 
     print("=========== {}, {} finished ===========".format(p_id, date))
